@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 1994 The Regents of the University of California.
+ * Copyright (c) 1994, 2000 The Regents of the University of California.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -10,10 +10,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
  * 4. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
@@ -59,7 +55,6 @@ void	domacro __P((int, char **));
 char   *domap __P((char *));
 void	doproxy __P((int, char **));
 char   *dotrans __P((char *));
-int     empty __P((fd_set *, int));
 void	fatal __P((char *));
 void	get __P((int, char **));
 struct cmd *getcmd __P((char *));
@@ -151,7 +146,3 @@ extern int	proxy;
 extern char	reply_string[];
 extern off_t	restart_point;
 extern int	NCMDS;
-
-#ifndef HAVE_GETPASS_DECL
-extern char *getpass __P((const char *));
-#endif
