@@ -10,10 +10,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
  * 4. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
@@ -48,22 +44,21 @@ static char sccsid[] = "@(#)talk.c	8.1 (Berkeley) 6/6/93";
 #include "talk.h"
 
 /*
- * talk:	A visual form of write. Using sockets, a two way 
- *		connection is set up between the two people talking. 
- *		With the aid of curses, the screen is split into two 
+ * talk:	A visual form of write. Using sockets, a two way
+ *		connection is set up between the two people talking.
+ *		With the aid of curses, the screen is split into two
  *		windows, and each users text is added to the window,
  *		one character at a time...
  *
  *		Written by Kipp Hickman
- *		
+ *
  *		Modified to run under 4.1a by Clem Cole and Peter Moore
  *		Modified to run between hosts by Peter Moore, 8/19/82
  *		Modified to run under 4.1c by Peter Moore 3/17/83
  */
 
-main(argc, argv)
-	int argc;
-	char *argv[];
+int
+main(int argc, char *argv[])
 {
 #ifndef HAVE___PROGNAME
 	extern char *__progname;
