@@ -10,10 +10,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
  * 4. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
@@ -100,6 +96,5 @@ extern void
 	ring_clearto P((Ring *ring));
 #endif	/* ENCRYPTION */
 
-extern void
-    ring_clear_mark(),
-    ring_mark();
+extern void ring_clear_mark P ((Ring *));
+extern void ring_mark P ((Ring *));
